pub struct TimedCache<K, V>(Arc<TimedCacheInner<K, V>>);Expand description
A cache with entries that “expire” after a per-cache time limit
Tuple Fields
0: Arc<TimedCacheInner<K, V>>Implementations
Sourceimpl<K, V> TimedCache<K, V>
impl<K, V> TimedCache<K, V>
Sourcepub fn get_if_fresh<Q>(&self, key: &Q) -> Option<Arc<TimedCacheEntry<V>>>
pub fn get_if_fresh<Q>(&self, key: &Q) -> Option<Arc<TimedCacheEntry<V>>>
Get a value if fresh, or None if it doesn’t exist or is expired
Sourcepub fn get_random_if_fresh(&self) -> Option<Arc<TimedCacheEntry<V>>>
pub fn get_random_if_fresh(&self) -> Option<Arc<TimedCacheEntry<V>>>
Get a random fresh value
Sourcepub fn insert_and_get(&self, key: K, value: V) -> Arc<TimedCacheEntry<V>>
pub fn insert_and_get(&self, key: K, value: V) -> Arc<TimedCacheEntry<V>>
Insert a K/V and return the data for the newly inserted value
Sourcepub fn force_trim(&self)
pub fn force_trim(&self)
Trims expired entries, ignoring last trim time.